@@ -1,6 +1,6 @@
 
 
-def discover_list_with_tab (p_thelist, p_taboption):
+def discover_list (p_thelist, p_taboption=0):
         for v_item in p_thelist:
                 if isinstance (v_item, list):
                         discover_list_with_tab(v_item,p_taboption)
